(* time utility routines for ocaml
   Copyright (C) 2002 Shawn Wagner <raevnos@pennmush.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
	 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
	 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)

(** Time utility functions to fill in gaps in the Unix library and to
be more to my liking. *)


(** {1 Getting the time}

These are like [Unix.BLAH], but storing the time in int32 rather than float. *)

external time : unit -> int32 = "stew_time_int32"
external gmtime: int32 -> Unix.tm = "stew_gmtime"
external localtime: int32 -> Unix.tm = "stew_localtime"
external mktime: Unix.tm -> int32 * Unix.tm = "stew_mktime"

(** {1 Pretty-printing a time} *)
(** Wrapper for the C strftime() function. See local documentation for
it for information on the string argument (strftime()'s format
argument) *)
external format_tm: string -> Unix.tm -> string = "stew_strftime_tm"

(** Same taking a time in seconds *)
val format_time: string -> int32 -> string

(** Returns the time as a string with trailing newline *)
external ctime: int32 -> string = "stew_ctime"
(** Same taking a [Unix.tm] *)
external asctime: Unix.tm -> string = "stew_asctime"

(** Time as a string without trailing newline *)
val time_string: int32 -> string
(** Same taking a [Unix.tm] *)
val tm_string: Unix.tm -> string

